package input;

# Written by David Augros <david@lightship.net>

use strict;
use vars qw( %month_numbers %extra );
require Tool;

print "Using BIND9 (DNS query log) format <parser/bind9.pm>\n" if $main::debug;

$extra{'total'} = 0;
$extra{'days'} = {};
$extra{'codered'} = 0;
$extra{'nimda'} = 0;
$extra{'search_terms'} = {};

data::init (
		Date     => 'count',
		Hour     => 'count',
		Client   => 'count',
		Domain   => 'count',
		Class    => 'count',
		Type     => 'count',
		TLD      => 'count',
		Requests => 'sum',
	);

sub parse
{
	my $line = shift or return undef;
	if ($line =~ /^(\S+\s+\d+)\s+([\d:]+).*?client\s+(\d{1,3}\.\d{1,3}\.\d{1,3}\.\d{1,3})\#\d+:\s+query:\s+(\S+)\s+(\S+)\s+(\S+)$/)
	{
# Initialize the variables that we can get out of
# each line first..
		my ($date, $time, $client, $domain, $class, $type) = ($1, $2, $3, $4, $5, $6);

# And now initialize all the variables we will use
# to get more information out of each field..
		my ($tmp, $day, $month, $hour, $minute, $second);
		($month, $day) = split (/\ /, $date);
		($hour, $minute, $second) = split (/\:/, $time);

		my $tld;
		if ($domain =~ /\./) {
			$domain =~ /([^\.]+)\.([^\.]+)$/;
			$tld = $2;
			$domain = $1 . "." . $2;
			$tld = lc($tld);
			$domain = lc($domain);
		} else {
			undef $domain;
		}
		if (!defined $extra{'days'}->{$date}) { $extra{'days'}->{$date} = 1; }
		++$extra{'total'};

		my %combined = (
					'Date'     => $date,
					'Hour'     => $hour,
					'TLD'      => $tld,
					'Client'   => $client,
					'Domain'   => $domain,
					'Class'    => $class,
					'Type'     => $type,
					'Requests' => 1
				);
		data::save (\%combined);
	}
	elsif ($::debug) { chomp ($line); print "$line\n"; }
}

sub extra
{
	my ($average, $days) = (0, 1);
	$days = scalar keys %{$extra{'days'}};
	$average = int (($extra{'total'} * 10) / $days) / 10;
	$::extra->{'Total requests'} = $extra{'total'};
	$::extra->{'Average requests per day'} = $average;
	$::extra->{'Reporting period'} = "$days days";
	my (@tmp, $key, $val);
}

1;
